@@ -37,6 +37,7 @@ class Logger:
         self.name = name
         self.handlers = ()
         self.parent = None
+        self.propagate = True
 
     def _level_str(self, level):
         l = _level_dict.get(level)
@@ -143,6 +144,9 @@ class Handler:
     def setFormatter(self, fmt):
         self.formatter = fmt
 
+    def format(self, record):
+        return self.formatter.format(record)
+
 
 class StreamHandler(Handler):
     def __init__(self, stream=None):
